##  Step 2: Grant Permissions to SAP LeanIX
  1. Go to the Azure portal.
  2. Choose the application you created.
  3. Assign the Azure API Center Service Reader role to the application. For detailed information, refer to the Microsoft documentation:
     * [Assign Azure roles using the Azure portal![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fazure%2Frole-based-access-control%2Frole-assignments-portal "https://learn.microsoft.com/en-us/azure/role-based-access-control/role-assignments-portal")
     * [Azure API Center Service Reader![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fazure%2Frole-based-access-control%2Fbuilt-in-roles%2Fintegration%23azure-api-center-service-reader "https://learn.microsoft.com/en-us/azure/role-based-access-control/built-in-roles/integration#azure-api-center-service-reader")


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio217ba93a3d7c48418da945049584a6d5_LowRes.png)
Assigning Roles to an Application
